@@ -29,6 +29,10 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
+#ifdef USE_XFT_FONT
+#include <X11/Xft/Xft.h>
+#endif
+
 typedef struct rp_window rp_window;
 typedef struct rp_screen rp_screen;
 typedef struct rp_action rp_action;
@@ -131,6 +135,9 @@ struct rp_group
   char *name;
   int number;
 
+  /* For determining the last group. */
+  int last_access;
+
   /* The list of windows participating in this group. */
   struct list_head mapped_windows, unmapped_windows;
 
@@ -151,7 +158,7 @@ struct rp_screen
   int xine_screen_num;          /* Our screen number for the Xinerama extension */
   Colormap def_cmap;
   Cursor rat;
-  unsigned long fg_color, bg_color; /* The pixel color. */
+  unsigned long fg_color, bg_color, fw_color, bw_color; /* The pixel color. */
 
   /* Here to abstract over the Xinerama vs X screens difference */
   int left, top, width, height;
@@ -168,6 +175,11 @@ struct rp_screen
   /* The number of the currently focused frame. One for each screen so
      when you switch screens the focus doesn't get frobbed. */
   int current_frame;
+
+#ifdef USE_XFT_FONT
+  XftFont *ft_font;
+  XftColor color;
+#endif
 };
 
 struct rp_action
@@ -226,6 +238,8 @@ struct rp_defaults
 
   char *fgcolor_string;
   char *bgcolor_string;
+  char *fwcolor_string;
+  char *bwcolor_string;
 
   int wait_for_key_cursor;
 
@@ -245,6 +259,10 @@ struct rp_defaults
   int warp;
 
   int history_size;
+  /* remove older history when adding the same again */
+  int history_compaction;
+  /* expand ! when compiled with libhistory */
+  int history_expansion;
 
   char *frame_selectors;
 
@@ -345,6 +363,7 @@ struct rp_input_line
   int   size;
   rp_completions *compl;
   Atom  selection;
+  int   history_id;
 };
 
 /* The hook dictionary. */
