@@ -27,7 +27,19 @@
 #define RET_SUCCESS 1
 #define RET_FAILURE 0
 
+#ifdef USE_XFT_FONT
+#include <X11/Xft/Xft.h>
+
+#define FONT_HEIGHT(s) ((s)->ft_font->ascent + (s)->ft_font->descent)
+#define FONT_ASCENT(s) ((s)->ft_font->ascent)
+
+#else
+
 #define FONT_HEIGHT(f) (rp_font_ascent + rp_font_descent)
+#define FONT_ASCENT(f) (rp_font_ascent)
+
+#endif
+
 #define MAX_FONT_WIDTH(f) (rp_font_width)
 
 #define WIN_EVENTS (StructureNotifyMask | PropertyChangeMask | ColormapChangeMask | FocusChangeMask)
@@ -52,6 +64,7 @@
 /* Error codes for group_delete_group() */
 #define GROUP_DELETE_GROUP_OK         0
 #define GROUP_DELETE_GROUP_NONEMPTY   1
+#define GROUP_DELETE_LAST_GROUP       2
 
 /* The list of groups. */
 extern struct list_head rp_groups;
@@ -102,8 +115,12 @@ extern Atom wm_take_focus;
 extern Atom wm_colormaps;
 
 /* netwm atoms. */
-Atom _net_wm_pid;
-Atom _net_supported;
+extern Atom _net_wm_pid;
+extern Atom _net_supported;
+extern Atom _net_wm_window_type;
+extern Atom _net_wm_window_type_dialog;
+extern Atom _net_wm_name;
+extern Atom utf8_string;
 
 /* mouse properties */
 extern int rat_x;
@@ -176,4 +193,9 @@ char *get_selection (void);
 
 void init_globals (void);
 
+/* Wrapper font functions to support Xft */
+
+void rp_draw_string (rp_screen *s, Drawable d, GC gc, int x, int y, char *string, int length);
+int rp_text_width (rp_screen *s, XFontSet font, char *string, int count);
+
 #endif
