@@ -242,8 +242,9 @@ update_modifier_map (void)
 }
 
 /* we need a keycode + modifier to generate the proper keysym (such as
-   @). */
-static void
+   @). Return 1 if successful, 0 otherwise. This function can fail if a
+   keysym doesn't map to a keycode. */
+static int
 keysym_to_keycode_mod (KeySym keysym, KeyCode *code, unsigned int *mod)
 {
   KeySym lower, upper;
@@ -256,6 +257,8 @@ keysym_to_keycode_mod (KeySym keysym, KeyCode *code, unsigned int *mod)
      mask. */
   if (upper == keysym && lower != keysym)
     *mod = ShiftMask;
+
+  return *code != 0;
 }
 
 /* Grab the key while ignoring annoying modifier keys including
@@ -270,7 +273,8 @@ grab_key (KeySym keysym, unsigned int modifiers, Window grab_window)
 
   /* Convert to a modifier mask that X Windows will understand. */
   modifiers = rp_mask_to_x11_mask (modifiers);
-  keysym_to_keycode_mod (keysym, &keycode, &mod);
+  if (!keysym_to_keycode_mod (keysym, &keycode, &mod))
+    return;
   PRINT_DEBUG (("keycode_mod: %ld %d %d\n", keysym, keycode, mod));
   modifiers |= mod;
 
@@ -424,15 +428,15 @@ read_key (KeySym *keysym, unsigned int *modifiers, char *keysym_name, int len)
 static void
 update_input_window (rp_screen *s, rp_input_line *line)
 {
-  int   prompt_width = XmbTextEscapement (defaults.font, line->prompt, strlen (line->prompt));
-  int   input_width  = XmbTextEscapement (defaults.font, line->buffer, line->length);
+  int   prompt_width = rp_text_width (s, defaults.font, line->prompt, -1);
+  int   input_width  = rp_text_width (s, defaults.font, line->buffer, line->length);
   int   total_width;
   GC lgc;
   XGCValues gv;
   int height;
 
   total_width = defaults.bar_x_padding * 2 + prompt_width + input_width + MAX_FONT_WIDTH (defaults.font);
-  height = (FONT_HEIGHT (defaults.font) + defaults.bar_y_padding * 2);
+  height = (FONT_HEIGHT (s) + defaults.bar_y_padding * 2);
 
   if (total_width < defaults.input_window_size + prompt_width)
     {
@@ -441,22 +445,22 @@ update_input_window (rp_screen *s, rp_input_line *line)
 
   XMoveResizeWindow (dpy, s->input_window,
                      bar_x (s, total_width), bar_y (s, height), total_width,
-                     (FONT_HEIGHT (defaults.font) + defaults.bar_y_padding * 2));
+                     (FONT_HEIGHT (s) + defaults.bar_y_padding * 2));
 
   XClearWindow (dpy, s->input_window);
   XSync (dpy, False);
 
-  XmbDrawString (dpy, s->input_window, defaults.font, s->normal_gc,
-		 defaults.bar_x_padding,
-		 defaults.bar_y_padding + rp_font_ascent,
-		 line->prompt,
-		 strlen (line->prompt));
+  rp_draw_string (s, s->input_window, s->normal_gc,
+                  defaults.bar_x_padding,
+                  defaults.bar_y_padding + FONT_ASCENT(s),
+                  line->prompt, 
+                  -1);
 
-  XmbDrawString (dpy, s->input_window, defaults.font, s->normal_gc,
-		 defaults.bar_x_padding + prompt_width,
-		 defaults.bar_y_padding + rp_font_ascent,
-		 line->buffer,
-		 line->length);
+  rp_draw_string (s, s->input_window, s->normal_gc, 
+                  defaults.bar_x_padding + prompt_width,
+                  defaults.bar_y_padding + FONT_ASCENT(s),
+                  line->buffer, 
+                  line->length);
 
   gv.function = GXxor;
   gv.foreground = s->fg_color ^ s->bg_color;
@@ -464,10 +468,10 @@ update_input_window (rp_screen *s, rp_input_line *line)
 
   /* Draw a cheap-o cursor - MkII */
   XFillRectangle (dpy, s->input_window, lgc,
-                  defaults.bar_x_padding + prompt_width + XmbTextEscapement (defaults.font, line->buffer, line->position),
+		  defaults.bar_x_padding + prompt_width + rp_text_width (s, defaults.font, line->buffer, line->position),
                   defaults.bar_y_padding,
-                  XmbTextEscapement (defaults.font, &line->buffer[line->position], 1),
-                  FONT_HEIGHT (defaults.font));
+		  rp_text_width (s, defaults.font, &line->buffer[line->position], 1),
+                  FONT_HEIGHT (s));
 
   XFlush (dpy);
   XFreeGC (dpy, lgc);
@@ -511,13 +515,13 @@ ring_bell (void)
 }
 
 char *
-get_input (char *prompt, completion_fn fn)
+get_input (char *prompt, int history_id, completion_fn fn)
 {
-  return get_more_input (prompt, "", fn);
+  return get_more_input (prompt, "", history_id, fn);
 }
 
 char *
-get_more_input (char *prompt, char *preinput,
+get_more_input (char *prompt, char *preinput, int history_id,
                 completion_fn compl_fn)
 {
   /* Emacs 21 uses a 513 byte string to store the keysym name. */
@@ -533,12 +537,10 @@ get_more_input (char *prompt, char *preinput,
   Window focus;
   int revert;
 
-#ifdef HAVE_HISTORY
   history_reset();
-#endif /* HAVE_READLINE_HISTORY_H */
 
   /* Create our line structure */
-  line = input_line_new (prompt, preinput, compl_fn);
+  line = input_line_new (prompt, preinput, history_id, compl_fn);
 
   /* We don't want to draw overtop of the program bar. */
   hide_bar (s);
