@@ -83,7 +83,7 @@ xrealloc (void *ptr, size_t size)
 }
 
 char *
-xstrdup (char *s)
+xstrdup (const char *s)
 {
   char *value;
   value = strdup (s);
@@ -322,7 +322,7 @@ static void
 print_version (void)
 {
   printf ("%s %s (built %s %s)\n", PACKAGE, VERSION, __DATE__, __TIME__);
-  printf ("Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006 Shawn Betts\n\n");
+  printf ("Copyright (C) 2000-2008 Shawn Betts\n\n");
 
   exit (EXIT_SUCCESS);
 }
@@ -526,6 +526,9 @@ init_defaults (void)
   defaults.padding_top    = 0;
   defaults.padding_bottom = 0;
 
+#ifdef USE_XFT_FONT
+  defaults.font_string = xstrdup (DEFAULT_XFT_FONT);
+#else
   /* Attempt to load a font */
   defaults.font = load_query_font_set (dpy, DEFAULT_FONT);
   if (defaults.font == NULL)
@@ -541,9 +544,12 @@ init_defaults (void)
 
   defaults.font_string = xstrdup (DEFAULT_FONT);
   set_extents_of_fontset (defaults.font);
+#endif
 
   defaults.fgcolor_string = xstrdup ("black");
   defaults.bgcolor_string = xstrdup ("white");
+  defaults.fwcolor_string = xstrdup ("black");
+  defaults.bwcolor_string = xstrdup ("black");
 
   defaults.wait_for_key_cursor = 1;
 
@@ -557,6 +563,8 @@ init_defaults (void)
   defaults.window_list_style = STYLE_COLUMN;
 
   defaults.history_size = 20;
+  defaults.history_compaction = True;
+  defaults.history_expansion = False;
   defaults.frame_selectors = xstrdup ("");
   defaults.maxundos = 20;
 }
@@ -681,6 +689,10 @@ main (int argc, char *argv[])
   PRINT_DEBUG (("_NET_WM_PID = %ld\n", _net_wm_pid));
   _net_supported = XInternAtom(dpy, "_NET_SUPPORTED", False);
   PRINT_DEBUG (("_NET_SUPPORTED = %ld\n", _net_supported));
+  _net_wm_window_type = XInternAtom(dpy, "_NET_WM_WINDOW_TYPE", False);
+  _net_wm_window_type_dialog = XInternAtom(dpy, "_NET_WM_WINDOW_TYPE_DIALOG", False);
+  _net_wm_name = XInternAtom(dpy, "_NET_WM_NAME", False);
+  utf8_string = XInternAtom(dpy, "UTF8_STRING", False);
 
   /* Setup signal handlers. */
   XSetErrorHandler(handler);
@@ -705,9 +717,7 @@ main (int argc, char *argv[])
   update_modifier_map ();
   init_user_commands();
   initialize_default_keybindings ();
-#ifdef HAVE_HISTORY
   history_load ();
-#endif /* HAVE_HISTORY */
 
   /* Scan for windows */
   if (screen_arg)
@@ -755,12 +765,23 @@ free_screen (rp_screen *s)
       frame_free (s, frame);
     }
 
+  deactivate_screen(s);
+
   XDestroyWindow (dpy, s->bar_window);
   XDestroyWindow (dpy, s->key_window);
   XDestroyWindow (dpy, s->input_window);
   XDestroyWindow (dpy, s->frame_window);
   XDestroyWindow (dpy, s->help_window);
 
+#ifdef USE_XFT_FONT
+  if (s->ft_font)
+    {
+      XftColorFree (dpy, DefaultVisual (dpy, s->screen_num),
+                    DefaultColormap (dpy, s->screen_num), &s->color);
+      XftFontClose (dpy, s->ft_font);
+    }
+#endif
+
   XFreeCursor (dpy, s->rat);
   XFreeColormap (dpy, s->def_cmap);
   XFreeGC (dpy, s->normal_gc);
@@ -773,9 +794,7 @@ clean_up (void)
 {
   int i;
 
-#ifdef HAVE_HISTORY
   history_save ();
-#endif /* HAVE_HISTORY */
 
   free_keymaps ();
   free_aliases ();
@@ -804,7 +823,9 @@ clean_up (void)
 
   free_xinerama();
 
+#ifndef USE_XFT_FONT
   XFreeFontSet (dpy, defaults.font);
+#endif
   free (defaults.window_fmt);
 
   XSetInputFocus (dpy, PointerRoot, RevertToPointerRoot, CurrentTime);
