@@ -270,11 +270,6 @@ init_screen (rp_screen *s, int screen_num)
 	       | StructureNotifyMask);
   XSync (dpy, False);
 
-  /* Add netwm support. FIXME: I think this is busted. */
-  XChangeProperty (dpy, RootWindow (dpy, screen_num),
-		   _net_supported, XA_ATOM, 32, PropModeReplace, 
-		   (unsigned char*)&_net_wm_pid, 1);
-
   /* Set the numset for the frames to our global numset. */
   s->frames_numset = rp_frame_numset;
 
@@ -301,6 +296,8 @@ init_screen (rp_screen *s, int screen_num)
 
   s->fg_color = BlackPixel (dpy, s->screen_num);
   s->bg_color = WhitePixel (dpy, s->screen_num);
+  s->fw_color = BlackPixel (dpy, s->screen_num);
+  s->bw_color = BlackPixel (dpy, s->screen_num);
 
   /* Setup the GC for drawing the font. */
   gv.foreground = s->fg_color;
@@ -325,7 +322,6 @@ init_screen (rp_screen *s, int screen_num)
                                        WhitePixel (dpy, s->screen_num),
                                        BlackPixel (dpy, s->screen_num));
   XSelectInput (dpy, s->key_window, KeyPressMask | KeyReleaseMask);
-  XMapWindow (dpy, s->key_window);
 
   /* Create the input window. */
   s->input_window = XCreateSimpleWindow (dpy, s->root, 0, 0, 1, 1,
@@ -342,7 +338,60 @@ init_screen (rp_screen *s, int screen_num)
                                         s->height, 0, s->fg_color, s->bg_color);
   XSelectInput (dpy, s->help_window, KeyPressMask);
 
+  activate_screen(s);
+
   XSync (dpy, 0);
+
+#ifdef USE_XFT_FONT
+  {
+     XRenderColor rc = {0, 0, 0, 0xFFFF};
+
+     if (!XftColorAllocValue (dpy, DefaultVisual (dpy, screen_num),
+                              DefaultColormap (dpy, screen_num), &rc, &s->color))
+       {
+         PRINT_ERROR(("Failed to allocate font color\n"));
+         s->ft_font = NULL;
+       }
+     else
+       {
+         s->ft_font = XftFontOpenName (dpy, screen_num, DEFAULT_XFT_FONT);
+         if (!s->ft_font)
+           {
+             PRINT_ERROR(("Failed to open font\n"));
+             XftColorFree (dpy, DefaultVisual (dpy, screen_num),
+                           DefaultColormap (dpy, screen_num), &s->color);
+           }
+       }
+  }
+#endif
+}
+
+void
+activate_screen (rp_screen *s)
+{
+  /* Add netwm support. FIXME: I think this is busted. */
+  XChangeProperty (dpy, RootWindow (dpy, s->screen_num),
+		   _net_supported, XA_ATOM, 32, PropModeReplace, 
+		   (unsigned char*)&_net_wm_pid, 1);
+
+  /* set window manager name */
+  XChangeProperty (dpy, RootWindow (dpy, s->screen_num),
+		   _net_wm_name, utf8_string, 8, PropModeReplace,
+		   (unsigned char*)"ratpoison", 9);
+  XMapWindow (dpy, s->key_window);
+}
+
+void
+deactivate_screen (rp_screen *s)
+{
+  /* Unmap its key window */
+  XUnmapWindow (dpy, s->key_window);
+
+  /* delete everything so noone sees them while we are not there */
+  XDeleteProperty (dpy, RootWindow (dpy, s->screen_num),
+		   _net_supported);
+  XDeleteProperty (dpy, RootWindow (dpy, s->screen_num),
+		   _net_wm_name);
 }
 
 static int
@@ -416,6 +465,8 @@ screen_update (rp_screen *s, int width, int height)
   oldwidth = s->width; oldheight = s->height;
   s->width = width; s->height = height;
 
+  XResizeWindow (dpy, s->help_window, width, height);
+
   list_for_each_entry (f, &s->frames, node)
     {
       f->x = (f->x*width)/oldwidth;
