@@ -29,8 +29,6 @@
 #define VERTICALLY 0
 #define HORIZONTALLY 1
 
-static rp_screen *frames_screen(rp_frame *);
-
 static void
 update_last_access (rp_frame *frame)
 {
@@ -110,7 +108,7 @@ set_frames_window (rp_frame *frame, rp_window *win)
   return find_window_number (last_win);
 }
 
-static rp_screen *
+rp_screen *
 frames_screen (rp_frame *frame)
 {
   int i;
@@ -806,9 +804,9 @@ remove_frame (rp_frame *frame)
              the new frame size. */
           if (cur->win_number != EMPTY)
             {
-              win = find_window_number (cur->win_number);
+              rp_window *new = find_window_number (cur->win_number);
               maximize_all_windows_in_frame (cur);
-              XRaiseWindow (dpy, win->w);
+              XRaiseWindow (dpy, new->w);
             }
         }
       else
@@ -1000,9 +998,9 @@ show_frame_message (char *msg)
       sbuf_concat (msgbuf, EMPTY_FRAME_MESSAGE);
     }
 
-  width = defaults.bar_x_padding * 2 + XmbTextEscapement (defaults.font, msgbuf->data,
+  width = defaults.bar_x_padding * 2 + rp_text_width (s, defaults.font, msgbuf->data,
 							  msgbuf->len);
-  height = (FONT_HEIGHT (defaults.font) + defaults.bar_y_padding * 2);
+  height = (FONT_HEIGHT (s) + defaults.bar_y_padding * 2);
 
   /* We don't want another frame indicator to be displayed on another
    * screen at the same time, so we hide it before bringing it back again.
@@ -1018,10 +1016,10 @@ show_frame_message (char *msg)
   XClearWindow (dpy, s->frame_window);
   XSync (dpy, False);
 
-  XmbDrawString (dpy, s->frame_window, defaults.font, s->normal_gc,
-		 defaults.bar_x_padding,
-		 defaults.bar_y_padding + rp_font_ascent,
-		 msgbuf->data, msgbuf->len);
+  rp_draw_string (s, s->frame_window, s->normal_gc,
+                  defaults.bar_x_padding,
+                  defaults.bar_y_padding + FONT_ASCENT(s),
+                  msgbuf->data, msgbuf->len);
 
   sbuf_free (msgbuf);
 }
